@@ -37,7 +37,7 @@ def get_firefox_home_file(needed_file):
 	path = None
 
 	for section in config.sections():
-		if config.has_option(section, "Default") and config.get(section, "Default") == 1:
+		if config.has_option(section, "Default") and config.get(section, "Default") == "1":
 			path = config.get (section, "Path")
 			break
 		elif path == None and config.has_option(section, "Path"):
@@ -100,7 +100,7 @@ def _on_handler_preferences(dialog):
 	show_primary_radio.connect ("toggled", toggled_cb, show_all_radio, show_primary_radio)
 	
 	notify_id = deskbar.GCONF_CLIENT.notify_add(GCONF_SHOW_ONLY_PRIMARY_KEY, lambda x, y, z, a: sync_ui(z.value.get_bool(), show_all_radio, show_primary_radio))
-	dialog.set_icon(deskbar.Utils.load_icon("deskbar-applet-small.png"))
+	dialog.set_icon_name("deskbar-applet")
 	dialog.show_all()
 	dialog.run()
 	dialog.destroy()
@@ -302,7 +302,7 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
 	def handle_endtag(self, tag):
 		tag = tag.lower()
 		if tag == "a":
-			if self.href.startswith("javascript:"):
+			if self.href == None or self.href.startswith("javascript:"):
 				return
 			
 			pixbuf = None
